import java.awt.AWTException;
import java.awt.Image;
import java.awt.MenuItem;
import java.awt.PopupMenu;
import java.awt.SystemTray;
import java.awt.Toolkit;
import java.awt.TrayIcon;
import java.awt.TrayIcon.MessageType;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.UnknownHostException;
import java.rmi.Naming;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Properties;



public class Start implements ActionListener {

	private static int _port;
	private final Score _s;
	private Properties conf;
	private TrayIcon trayIcon;
	
	private Start() throws RemoteException, MalformedURLException, AWTException{

		//preparation de l'arret
		Runtime.getRuntime ().addShutdownHook (new ShutdownHook());
		
		//mise en place de l'icone
		Image image = Toolkit.getDefaultToolkit().getImage(getClass().getResource("/pic/ico.png"));
		PopupMenu popup = new PopupMenu();
		MenuItem exit = new MenuItem("Exit");
		exit.addActionListener(this);
		popup.add(exit);
		trayIcon = new TrayIcon(image,"GUSC",popup);
		//trayIcon.setImageAutoSize(true);
		SystemTray.getSystemTray().add(trayIcon);
		
		//chargement de la conf
		conf = new Properties();
		try {
			FileInputStream file = null;
			file = new FileInputStream("score.properties");
			conf.load(file);
			file.close();
			//return conf.getProperty(label);
		} catch (IOException e) {
			conf.setProperty("SCORE0", "user:0");
		}
		
		//demarage du service rmi
		java.rmi.registry.LocateRegistry.createRegistry(_port);
		//creation de l'objet a partager
		_s = new Score(conf,this);
		Naming.rebind("rmi://127.0.0.1:"+_port+"/Score",_s);
		System.out.println("serveur pret sur port "+_port);
	}

	public static void main(String[] args) throws RemoteException, MalformedURLException, UnknownHostException, AWTException {
		if(args.length!=1){
			System.err.println("start [port]");
		}
		_port = Integer.parseInt(args[0]);
		
		new Start();
	}

	
	class ShutdownHook extends Thread
	{
		public ShutdownHook ()
		{
		}
		public void run ()
		{
			//arret, sauvegarde...
			try {
				//on reconstruit la conf
				ArrayList<String> data = _s.getList();
				int i = 0;
				for(String line:data){
					conf.setProperty("SCORE"+i, line);
				i++;	
				}
			FileOutputStream os = new FileOutputStream("score.properties");
			conf.store(os, "scoring");
			os.close();
			} catch (Exception e) {
				e.printStackTrace();
			}
							
		}

	}

	public void pop(String message){
		trayIcon.displayMessage(null,message,MessageType.NONE);
	}

	@Override
	public void actionPerformed(ActionEvent arg0) {
		System.exit(0);
		
	}
	
}
